@@ -16,7 +16,7 @@ use base qw(Exporter);
 
 our @EXPORT_OK = ();
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 #{{{sub new
 sub new {
@@ -255,22 +255,40 @@ Create, set up, and return a Content object.
 
 =head1 REQUIRED ARGUMENTS
 
+None required.
+
 =head1 OPTIONS
 
+n/a
+
 =head1 DIAGNOSTICS
 
+n/a
+
 =head1 EXIT STATUS
 
+0 on success.
+
 =head1 CONFIGURATION
 
+None required.
+
 =head1 DEPENDENCIES
 
 =head1 INCOMPATIBILITIES
 
+None known.
+
 =head1 BUGS AND LIMITATIONS
 
+None known.
+
 =head1 AUTHOR
 
 Daniel David Parry <perl@ddp.me.uk>
 
 =head1 LICENSE AND COPYRIGHT
+
+LICENSE: http://dev.perl.org/licenses/artistic.html
+
+COPYRIGHT: Daniel David Parry <perl@ddp.me.uk>
